pub async fn load_offset_page<T, F, Fut>(
limit: u64,
offset: u64,
max_limit: u64,
fetch: F,
) -> Result<OffsetPage<T>>Expand description
Loads an offset page by clamping limit, invoking fetch, and wrapping the result.
pub async fn load_offset_page<T, F, Fut>(
limit: u64,
offset: u64,
max_limit: u64,
fetch: F,
) -> Result<OffsetPage<T>>Loads an offset page by clamping limit, invoking fetch, and wrapping the result.