parse_string_id_cursor

Function parse_string_id_cursor 

pub fn parse_string_id_cursor(
    value: Option<String>,
    id: Option<i64>,
    value_name: &str,
) -> Result<Option<(String, i64)>>
Validates a string value plus numeric id cursor pair.

Errors

Returns an error when the tuple is incomplete, the string value is blank, or the id is not positive.