pub struct CreatedAtCursorQuery {
pub after_created_at: Option<DateTime<Utc>>,
pub after_id: Option<i64>,
}Expand description
Cursor query for resources ordered by creation time and numeric id.
Fields
after_created_at: Option<DateTime<Utc>>Cursor creation timestamp.
after_id: Option<i64>Cursor numeric id used as a stable tie breaker.