pub struct DateTimeIdCursor {
pub value: DateTime<Utc>,
pub id: i64,
}Expand description
Timestamp plus numeric id cursor for resources sorted by time and then id.
Fields
value: DateTime<Utc>Cursor timestamp.
id: i64Cursor numeric id used as a stable tie breaker.