pub struct DateTimeStringCursor {
pub value: DateTime<Utc>,
pub id: String,
}Expand description
Timestamp plus string id cursor for resources sorted by time and then string id.
Fields
value: DateTime<Utc>Cursor timestamp.
id: StringCursor string id used as a stable tie breaker.