pub struct EnabledPriorityIdCursor {
pub enabled: bool,
pub priority: i32,
pub id: i64,
}Expand description
Enabled flag, priority, and numeric id cursor for prioritized toggle-like resources.
Fields
enabled: boolCursor enabled flag.
priority: i32Cursor priority value.
id: i64Cursor numeric id used as a stable tie breaker.