pub struct StringIdCursor {
pub value: String,
pub id: i64,
}Expand description
String value plus numeric id cursor for resources sorted by text and then id.
Fields
value: StringCursor string value.
id: i64Cursor numeric id used as a stable tie breaker.