pub struct UpdatedAtCursorQuery {
pub after_updated_at: Option<DateTime<Utc>>,
pub after_id: Option<i64>,
}Expand description
Cursor query for resources ordered by update time and numeric id.
Fields
after_updated_at: Option<DateTime<Utc>>Cursor update timestamp.
after_id: Option<i64>Cursor numeric id used as a stable tie breaker.